//
// OCSINVENTORY-NG 
// Copyleft Guillaume PROTET 2011
// Web : http://www.ocsinventory-ng.org
//
// This code is open source and may be copied and modified as long as the source
// code is always made freely available.
// Please refer to the General Public Licence http://www.gnu.org/ or Licence.txt
//
//

#ifdef __OBJC__
    #import <Cocoa/Cocoa.h>
#endif

@interface ocscontact : NSObject {

}

@end
